/** @odoo-module **/

// ensure mail override is applied first.
import '@mail/../tests/helpers/mock_server';
import MockServer from 'web.MockServer';
import { datetime_to_str } from 'web.time';

MockServer.include({
    //--------------------------------------------------------------------------
    // Private Mocked Methods
    //--------------------------------------------------------------------------

    /**
     * Simulates `_systray_get_calendar_event_domain` on `res.users`.
     *
     * @private
     */
    _mockResUsers_SystrayGetCalendarEventDomain() {
        const startDate = new Date();
        const endDate = new Date();
        endDate.setUTCHours(23, 59, 59, 999);
        const currentPartnerAttendeeIds = this._mockSearch('calendar.attendee', [[['partner_id', '=', this.currentPartnerId]]], {});
        return [
            '&',
                '|',
                    '&',
                        '|',
                            ['start', '>=', datetime_to_str(startDate)],
                            ['stop', '>=', datetime_to_str(startDate)],
                        ['start', '<=', datetime_to_str(endDate)],
                    '&',
                        ['allday', '=', true],
                        ['start_date', '=', datetime_to_str(startDate)],
                ['attendee_ids', 'in', currentPartnerAttendeeIds],
        ];
    },

    /**
     * Simulates `systray_get_activities` on `res.users`.
     *
     * @override
     */
    _mockResUsersSystrayGetActivities() {
        const activities = this._super(...arguments);
        const meetingsLines = this._mockSearchRead(
            'calendar.event',
            [
                this._mockResUsers_SystrayGetCalendarEventDomain(),
                ['id', 'start', 'name', 'allday', 'attendee_status']
            ],
            { order: 'start' }
        ).filter(meetingLine => meetingLine['attendee_status'] !== 'declined');
        if (meetingsLines.length) {
            activities.unshift({
                meetings: meetingsLines,
                model: 'calendar.event',
                name: 'Today\'s Meetings',
                type: 'meeting',
            });
        }
        return activities;
    },
});
